#include "gyroscope.h"

#include <QDebug>

Gyroscope::Gyroscope(double offset, double Te, QObject *parent)
    : QObject(parent), m_offset(offset), m_Te(Te)
{
    settings = new RTIMUSettings("/etc/balancingBot","RTIMULib");
    imu = RTIMU::createIMU(settings);
    if ((imu == NULL) || (imu->IMUType() == RTIMU_TYPE_NULL)) {
            qDebug()<<"gyro non trouvé !!";
        }
    imu->IMUInit();
    imu->setSlerpPower(0.02);
    imu->setGyroEnable(true);
    imu->setAccelEnable(true);
    imu->setCompassEnable(true);

    qDebug()<<"période gyro : "<<imu->IMUGetPollInterval()<<"ms";
    if (m_Te<imu->IMUGetPollInterval())         qDebug()<<"Te trop rapide !!"<<m_Te<<"ms";
    else if (m_Te==imu->IMUGetPollInterval())   qDebug()<<"Te optimum"<<m_Te<<"ms";
    else                                        qDebug()<<"Te peut-être plus rapide"<<m_Te<<"ms";

    tictoc.setInterval(m_Te);
    connect(&tictoc,SIGNAL(timeout()),
            this,SLOT(process()));
    tictoc.start();
}

void Gyroscope::process()
{
    while(imu->IMURead());
    imuData = imu->getIMUData();
    m_val=imuData.fusionPose.x()-m_offset;
    if (m_val<-RTMATH_PI) m_val=m_val+2*RTMATH_PI;
    if (m_val>RTMATH_PI)  m_val=m_val-2*RTMATH_PI;
    emit newVal(m_val);
}

int Gyroscope::Te() const
{
    return m_Te;
}
